<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main Poolax Core Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */

final class Poolax_Extension {

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */

	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';


	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Elementor_Test_Extension The single instance of the class.
	 */

	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Test_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'init' ] );
	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated

		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version

		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version

		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}


		// Add Plugin actions

		add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );


        // Register widget scripts

		add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'widget_scripts' ]);


		// Specific Register widget scripts

		// add_action( 'elementor/frontend/after_register_scripts', [ $this, 'poolax_regsiter_widget_scripts' ] );
		// add_action( 'elementor/frontend/before_register_scripts', [ $this, 'poolax_regsiter_widget_scripts' ] );


        // category register

		add_action( 'elementor/elements/categories_registered',[ $this, 'poolax_elementor_widget_categories' ] );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'poolax' ),
			'<strong>' . esc_html__( 'Poolax Core', 'poolax' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'poolax' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */

			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'poolax' ),
			'<strong>' . esc_html__( 'Poolax Core', 'poolax' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'poolax' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(

			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'poolax' ),
			'<strong>' . esc_html__( 'Poolax Core', 'poolax' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'poolax' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */

	public function init_widgets() {

		$widget_register = \Elementor\Plugin::instance()->widgets_manager;

		// Header Include file & Widget Register
		require_once( POOLAX_ADDONS . '/header/header.php' );
		require_once( POOLAX_ADDONS . '/header/header2.php' );

		$widget_register->register ( new \Poolax_Header() );
		$widget_register->register ( new \Poolax_Header2() );


		// Include All Widget Files
		foreach($this->Poolax_Include_File() as $widget_file_name){
			require_once( POOLAX_ADDONS . '/widgets/poolax-'."$widget_file_name".'.php' );
		}
		// All Widget Register
		foreach($this->Poolax_Register_File() as $name){
			$widget_register->register ( $name );
		}
		
	}

	public function Poolax_Include_File(){
		return [
			'banner', 
			'banner2', 
			'section-title', 
			'button', 
			'blog', 
			'service', 
			'testimonial', 
			'team', 
			'team-info', 
			'image', 
			'contact-info', 
			'contact-form', 
			'counterup', 
			'faq', 
			'brand-logo', 
			'cta', 
			'gallery', 
			'info-box', 
			'portfolio', 
			'portfolio-info',
			'newsletter', 
			'menu-select', 
			'footer-widgets', 

			'service-list',
			'social',
			'gallery-filter', 
			'download-button',
			'animated-shape', 
			'arrows', 
			'tab-builder', 
			'skill', 
			'about-us', 
			'step', 
			'offer', 
			'features', 
			'video', 
			'price',
			'choose-us',
			'marquee',
			'classes',
		];
	}

	public function Poolax_Register_File(){
		return [
			new \Poolax_Banner() ,
			new \Poolax_Banner2() ,
			new \Poolax_Section_Title(),
			new \Poolax_Button(),
			new \Poolax_Blog(),
			new \Poolax_Service(),
			new \Poolax_Testimonial(),
			new \Poolax_Team(),
			new \Poolax_Team_info(),
			new \Poolax_Image(),
			new \Poolax_Contact_Info(),
			new \Poolax_Contact_Form(),
			new \Poolax_Counterup(),
			new \Poolax_Faq(),
			new \Poolax_Brand_Logo(),
			new \Poolax_Cta(),
			new \Poolax_Gallery(),
			new \Poolax_Info_Box(),
			new \poolax_Portfolio(),
			new \poolax_Portfolio_Info(),
			new \poolax_Newsletter(),
			new \Poolax_Menu(),
			new \Poolax_Footer_Widgets(),

			new \Poolax_Service_List(),
			new \Poolax_Social(),
			new \Poolax_Gallery_Filter(),
			new \poolax_Download_Button(),
			new \Poolax_Animated_Shape(),
			new \Poolax_Arrows(),
			new \Poolax_Tab_Builder(),
			new \poolax_Skill(),
			new \Poolax_About_Us(),
			new \poolax_Step(),
			new \Poolax_Offer(),
			new \Poolax_Features(),
			new \poolax_Video(),
			new \Poolax_Price(),
			new \Poolax_Choose_Us(),
			new \poolax_Marquee(),
			new \Poolax_Classes(),
		];
	}

    public function widget_scripts() {

        wp_enqueue_script(
            'poolax-frontend-script',
            POOLAX_PLUGDIRURI . 'assets/js/poolax-frontend.js',
            array('jquery'),
            false,
            true
		);

	}


	// public function poolax_regsiter_widget_scripts( ) {

	// 	wp_register_script(
 //            'poolax-tilt',
 //            POOLAX_PLUGDIRURI . 'assets/js/tilt.jquery.min.js',
 //            array('jquery'),
 //            false,
 //            true
	// 	);
	// }


    function poolax_elementor_widget_categories( $elements_manager ) {

        $elements_manager->add_category(
            'poolax',
            [
                'title' => __( 'Poolax', 'poolax' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );

        $elements_manager->add_category(
            'poolax_footer_elements',
            [
                'title' => __( 'Poolax Footer Elements', 'poolax' ),
                'icon' 	=> 'fa fa-plug',
            ]
		);

		$elements_manager->add_category(
            'poolax_header_elements',
            [
                'title' => __( 'Poolax Header Elements', 'poolax' ),
                'icon' 	=> 'fa fa-plug',
            ]
        );
	}
}

Poolax_Extension::instance();